You are viewing a plain text version of this content. The canonical link for it is here.
Posted to surefire-commits@maven.apache.org by kr...@apache.org on 2010/12/21 21:55:12 UTC

svn commit: r1051648 - in /maven/surefire/trunk: maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/ maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/ maven-surefire-plugin/src/site/ maven-surefire-plugin/src/site/...

Author: krosenvold
Date: Tue Dec 21 20:55:12 2010
New Revision: 1051648

URL: http://svn.apache.org/viewvc?rev=1051648&view=rev
Log:
[SUREFIRE-636/669/668] Documentation run

Modified:
    maven/surefire/trunk/maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/IntegrationTestMojo.java
    maven/surefire/trunk/maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/SurefirePlugin.java
    maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/junit.apt.vm
    maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/providers.apt.vm
    maven/surefire/trunk/maven-surefire-plugin/src/site/apt/index.apt
    maven/surefire/trunk/maven-surefire-plugin/src/site/site.xml

Modified: maven/surefire/trunk/maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/IntegrationTestMojo.java
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/IntegrationTestMojo.java?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================
--- maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/junit.apt.vm (original)
+++ maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/junit.apt.vm Tue Dec 21 20:55:12 2010
@@ -38,7 +38,7 @@ Using JUnit
   has run. Form 2.7 and on only run valid JUnit tests for all versions of JUnit, where older versions
   would run invalid tests that satisfied a naming convention.
 
-  When upgrading from a version < 2.7 to a newer version, the build can be run with
+  When upgrading from a version &lt; 2.7 to a newer version, the build can be run with
   the flag -Dsurefire.junit4.upgradecheck which will notify you of any tests that
   will not be run any more (and the build fails). This is only meant to be used as a tool
   when upgrading to check that all your tests will be run. It is a transitional

Modified: maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/providers.apt.vm
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/providers.apt.vm?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================
--- maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/providers.apt.vm (original)
+++ maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/providers.apt.vm Tue Dec 21 20:55:12 2010
@@ -1,12 +1,12 @@
  ------
- Configuring providers
+ Selecting providers
  ------
  Kristian Rosenvold <kr...@apache.org>
  ------
  2010-12-04
  ------
 
-Configuring providers
+Selecting providers
 
 * Selecting a provider
 
@@ -22,12 +22,12 @@ Configuring providers
             <plugin>
                 <groupId>org.apache.maven.plugins</groupId>
                 <artifactId>maven-surefire-plugin</artifactId>
-                <version>${surefire.version}</version>
+                <version>${project.version}</version>
                 <dependencies>
                     <dependency>
                         <groupId>org.apache.maven.surefire</groupId>
                         <artifactId>surefire-junit47</artifactId>
-                        <version>${surefire.version}</version>
+                        <version>${project.version}</version>
                     </dependency>
                 </dependencies>
             </plugin>
@@ -37,3 +37,6 @@ Configuring providers
   The providers supplied with surefire are surefire-junit3, surefire-junit4, surefire-junit47 and surefire-testng.
   Please note that forcing a provider still requires that the test framework is properly set up on your project classpath.
 
+  You can also specify multiple providers as dependencies, and they will all be run and produce a common report.
+  This may be especially handy with external providers, since there are few use-cases for combining the included providers.
+

Modified: maven/surefire/trunk/maven-surefire-plugin/src/site/apt/index.apt
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-surefire-plugin/src/site/apt/index.apt?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================
--- maven/surefire/trunk/maven-surefire-plugin/src/site/apt/index.apt (original)
+++ maven/surefire/trunk/maven-surefire-plugin/src/site/apt/index.apt Tue Dec 21 20:55:12 2010
@@ -93,4 +93,4 @@ Maven Surefire Plugin
 
   * {{{./examples/configuring-classpath.html}Configuring the Classpath}}
 
-  []
+  * {{{./examples/providers.html}Selecting providers}}

Modified: maven/surefire/trunk/maven-surefire-plugin/src/site/site.xml
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-surefire-plugin/src/site/site.xml?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================
--- maven/surefire/trunk/maven-surefire-plugin/src/site/site.xml (original)
+++ maven/surefire/trunk/maven-surefire-plugin/src/site/site.xml Tue Dec 21 20:55:12 2010
@@ -40,7 +40,7 @@
       <item name="Debugging Tests" href="examples/debugging.html"/>
       <item name="System Properties" href="examples/system-properties.html"/>
       <item name="Configuring the Classpath" href="examples/configuring-classpath.html"/>
-      <item name="Choosing providers" href="examples/providers.html"/>
+      <item name="Selecting providers" href="examples/providers.html"/>
     </menu>
   </body>
 </project>
--- maven/surefire/trunk/maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/IntegrationTestMojo.java (original)
+++ maven/surefire/trunk/maven-failsafe-plugin/src/main/java/org/apache/maven/plugin/failsafe/IntegrationTestMojo.java Tue Dec 21 20:55:12 2010
@@ -203,10 +203,16 @@ public class IntegrationTestMojo
     private String test;
 
     /**
      * List of patterns (separated by commas) used to specify the tests that should be included in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default includes will be
-     * <code>**&#47;IT*.java   **&#47;*IT.java   **&#47;*ITCase.java</code>.  This parameter is ignored if
-     * TestNG suiteXmlFiles are specified.
+     * <code><br/>
+        &lt;includes><br/>
+            &nbsp;&lt;include>**&#47;Test*.java&lt;/include><br/>
+            &nbsp;&lt;include>**&#47;*Test.java&lt;/include><br/>
+            &nbsp;&lt;include>**&#47;*TestCase.java&lt;/include><br/>
+        &lt;/includes><br/>
+     * </code>
+     * This parameter is ignored if TestNG suiteXmlFiles are specified.
      *
      * @parameter
      */
@@ -215,8 +221,12 @@ public class IntegrationTestMojo
     /**
      * List of patterns (separated by commas) used to specify the tests that should be excluded in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default excludes will be
-     * <code>**&#47;*$*</code> (which excludes all inner classes).  This parameter is ignored if
-     * TestNG suiteXmlFiles are specified.
+     * <code><br/>
+        &lt;excludes><br/>
+            &nbsp;&lt;exclude>**&#47;*$*&lt;/exclude><br/>
+        &lt;/excludes><br/>
+     * </code>
+     * (which excludes all inner classes).  This parameter is ignored if TestNG suiteXmlFiles are specified.
      *
      * @parameter
      */
@@ -203,10 +203,16 @@ public class IntegrationTestMojo
 
     /**
-     * List of patterns (separated by commas) used to specify the tests that should be included in testing. When not
+     * A list of <include> elements used to specify the the tests that should be included in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default includes will be

Modified: maven/surefire/trunk/maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/SurefirePlugin.java
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/SurefirePlugin.java?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================
--- maven/surefire/trunk/maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/SurefirePlugin.java (original)
+++ maven/surefire/trunk/maven-surefire-plugin/src/main/java/org/apache/maven/plugin/surefire/SurefirePlugin.java Tue Dec 21 20:55:12 2010
@@ -138,11 +138,9 @@ public class SurefirePlugin
      * A dependency scope to exclude from the test classpath
      * The scope can be one of the following scopes:
      * <p/>
-     * <ul>
-     * <li><i>compile</i> - system, provided, compile
+     * <ul><li><i>compile</i> - system, provided, compile
      * <li><i>runtime</i> - compile, runtime
-     * <li><i>test</i> - system, provided, compile, runtime, test
-     * </ul>
+     * <li><i>test</i> - system, provided, compile, runtime, test</ul>
      *
      * @parameter default-value=""
      * @since 2.6
@@ -185,10 +183,16 @@ public class SurefirePlugin
     private String test;
 
     /**
      * List of patterns (separated by commas) used to specify the tests that should be included in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default includes will be
-     * <code>**&#47;Test*.java   **&#47;*Test.java   **&#47;*TestCase.java</code>.  This parameter is ignored if
-     * TestNG suiteXmlFiles are specified.
+     * <code><br/>
+        &lt;includes><br/>
+            &nbsp;&lt;include>**&#47;Test*.java&lt;/include><br/>
+            &nbsp;&lt;include>**&#47;*Test.java&lt;/include><br/>
+            &nbsp;&lt;include>**&#47;*TestCase.java&lt;/include><br/>
+        &lt;/includes><br/>
+     * </code>
+     * This parameter is ignored if TestNG suiteXmlFiles are specified.
      *
      * @parameter
      */
@@ -197,8 +201,12 @@ public class SurefirePlugin
     /**
      * List of patterns (separated by commas) used to specify the tests that should be excluded in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default excludes will be
-     * <code>**&#47;*$*</code> (which excludes all inner classes).  This parameter is ignored if
-     * TestNG suiteXmlFiles are specified.
+     * <code><br/>
+        &lt;excludes><br/>
+            &nbsp;&lt;exclude>**&#47;*$*&lt;/exclude><br/>
+        &lt;/excludes><br/>
+     * </code>
+     * (which excludes all inner classes).  This parameter is ignored if TestNG suiteXmlFiles are specified.
      *
      * @parameter
      */
@@ -562,10 +570,8 @@ public class SurefirePlugin
 
     /**
      * Defines the order the tests will be run in. Supported values are alphabetical, reversealphabetical
-     * random, hourly (alphabetical on even hours, reverse alphabetical on odd hours) and filesystem.
-     * <p/>
-     * Not supplying a value for this setting will run tests in filesystem order.
-     * <p/>
+     * random, hourly (alphabetical on even hours, reverse alphabetical on odd hours) and filesystem.<p/>
+     * Not supplying a value for this setting will run tests in filesystem order. <p/>
      * Odd/Even for hourly is determined at the time the of scanning the classpath, meaning it could change during
      * a multi-module build.
      *
@@ -185,10 +183,16 @@ public class SurefirePlugin
 
     /**
-     * List of patterns (separated by commas) used to specify the tests that should be included in testing. When not
+     * A list of &lt;include> elements used to specify the the tests that should be included in testing. When not
      * specified and when the <code>test</code> parameter is not specified, the default includes will be

Modified: maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/junit.apt.vm
URL: http://svn.apache.org/viewvc/maven/surefire/trunk/maven-surefire-plugin/src/site/apt/examples/junit.apt.vm?rev=1051648&r1=1051647&r2=1051648&view=diff
==============================================================================